@@ -8,17 +8,22 @@ deactivate > /dev/null 2>&1
 
 basename="$( basename "$( pwd )" )"
 name="${1:-${basename}}"
-[[ "${name}" != "${PEN_BASENAME}" ]]  || name="${PEN_GIT}"
+url="${name}"
+if [[ "${name}" == "${PEN_BASENAME}" ]]; then
+  url="${PEN_GIT}"
+  name="${PEN_BASENAME}"
+fi
 
 command="/usr/local/bin/python3.8"
 if ! test -n "${DARWIN}"; then
   command="sudo /bin/python3.8"
 fi
 
-if error="$( ${command} -m pip install --upgrade "${name}" 2>&1 )"; then
-  info.sh upgrade "${name}"
+
+if error="$( ${command} -m pip uninstall "${name}" -y 2>&1 && ${command} -m pip install --upgrade "${url}" 2>&1 )"; then
+  info.sh install "${name}"
 else
-  error.sh upgrade "${name}" "${error}"; exit 1
+  error.sh install "${name}" "${error}"; exit 1
 fi
 
 unset starting error command
